/* ==========================================================
 * Program: 20-HorseshoeP1P2.cpp
 * ==========================================================
 * The program checks the covering relations between some 
 * h-sets related to the connecting orbit between P1 and P2
 * From the program 06:
 * 	P1 ~ 1.098956671;	dom. eigenvalue approx. 264
	P2 ~ 1.294511656;	dom. eigenvalue approx. 28
 * ==========================================================*/ 

#include <iostream>
using namespace std;

#include "capd/capdlib.h"
using namespace capd;
using namespace capd::alglib;
using namespace capd::matrixAlgorithms;
#include "capd/covrel/HSet2D.h"
#include "capd/dynsys/DynSysMap.h"

#include "utils.h"
typedef capd::covrel::HSet2D<DMatrix, IMatrix> HSet2D;


int main(int argc, char* argv[])
{  	
	cout.precision(8);
   	mojUklad hyperion;					// structure storing Poincare map of Hyperion rotation system, see utils
   	
	//---------------------------------stationary points------------------------------------------------------	
	interval z1=1.099105177037064;
	interval z2=1.294219468594181;			// approximately
	IMatrix Mv1(3,3), Mv2(3,3);
	IVector p1=hyperion.pStNaPi2(z1,Mv1);	// rigorously, small intervals containing P1 and P2
	IVector p2=hyperion.pStNaPi2(z2,Mv2);
	// cout << "Mv1 = " << Mv1 << ", " << "\nMv2 = " << Mv2 << endl;	// eigenvectors' matrices
	
	//------------------------------------the base cubes of h-sets ----------------------------------------------------
	double r = pow(10,-3);
	IVector b1(3), b2(3);
	b1[0]=interval(-0.8*r,0.8*r);
	b1[1]=interval(-180*r,80*r);
	b2[0]=interval(-10*r,5*r);
	b2[1]=interval(-75*r,200*r);
	
   	//--------------------------------- covering check (all with 10x10 griding)------------------------
	try{
		if(hyperion.covers(b1,Mv1,p1,b1,Mv1,p1,10,10))			
		{			
			cout << "Covering! N0 =P=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b1,Mv1,p1,b2,Mv2,p2,10,10))
		{			
			cout << "Covering! N0 =P=> N1" << endl;				
			cout << "----------------------------------------------------" << endl;	
		}
		if(hyperion.covers(b2,Mv2,p2,b2,Mv2,p2,10,10))
		{			
			cout << "Covering! N1 =P=> N1" << endl;			
			cout << "----------------------------------------------------" << endl;	
		}
		if(hyperion.covers(b2,Mv2,p2,b1,Mv1,p1,10,10))
		{			
			cout << "Covering! N1 =P=> N0" << endl;			
			cout << "----------------------------------------------------" << endl;	
		}
		}
	catch(exception& e)
		{
    		cout << "\n\nException caught: "<< e.what() << endl;
		}
  return 0;
} 

/* OUTPUT:
Covering! N0 =P=> N0
----------------------------------------------------
Covering! N0 =P=> N1
----------------------------------------------------
Covering! N1 =P=> N1
----------------------------------------------------
Covering! N1 =P=> N0
----------------------------------------------------

*/
